@@ -1,18 +1,30 @@
 // AlphIO.cpp
 //
-/////////////////////////////////////////////////////////////////////////////
+// Copyright (c) 2007 The Dasher Team
 //
-// Copyright (c) 2002 Iain Murray
+// This file is part of Dasher.
 //
-/////////////////////////////////////////////////////////////////////////////
+// Dasher is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+//
+// Dasher is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Dasher; if not, write to the Free Software 
+// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 #include "../../Common/Common.h"
-
 #include "AlphIO.h"
 
+#include <iostream>
+
 using namespace Dasher;
 using namespace std;
-//using namespace expat;
 
 // Track memory leaks on Windows to the line that new'd the memory
 #ifdef _WIN32
@@ -117,6 +129,8 @@ std::string CAlphIO::GetDefault() {
 }
 
 const CAlphIO::AlphInfo & CAlphIO::GetInfo(const std::string &AlphID) {
+  std::cout << "Getting info for " << AlphID << std::endl;
+
   if(Alphabets.count(AlphID) != 0) {
     // if we have the alphabet they ask for, return it
     Alphabets[AlphID].AlphID = AlphID;        // Ensure consistency
