@@ -188,6 +188,8 @@ CDasherNode *CAlphabetManager::CreateGroupNode(CDasherNode *pParent, SGroupInfo
 CDasherNode *CAlphabetManager::CreateSymbolNode(CDasherNode *pParent, symbol iSymbol, std::vector<unsigned int> *pCProb, unsigned int iStart, unsigned int iEnd, unsigned int iMin, unsigned int iMax, symbol iExistingSymbol, CDasherNode *pExistingChild) {
   // TODO: Node deletion etc.
 
+  //  std::cout << iSymbol << " " << m_pNCManager->GetStartConversionSymbol() << std::endl;
+
 #ifdef WIN32
   unsigned int iLbnd = (((*pCProb)[iStart-1] - (*pCProb)[iMin-1]) * 
 	  (unsigned __int64)(m_pNCManager->GetLongParameter(LP_NORMALIZATION))) / 
@@ -217,8 +219,14 @@ CDasherNode *CAlphabetManager::CreateSymbolNode(CDasherNode *pParent, symbol iSy
     DASHER_ASSERT(static_cast<SAlphabetData *>(pExistingChild->m_pUserData)->iOffset == pParentData->iOffset + 1);
 
   }
+  // TODO: Need to fix fact that this is created even when control mode is switched off
   else if(iSymbol == m_pNCManager->GetControlSymbol()) {                                                                               
     pNewNode = m_pNCManager->GetRoot(1, pParent, iLbnd, iHbnd, &(pParentData->iOffset));                                           
+
+    // For now, just hack it so we get a normal root node here
+    if(!pNewNode) {
+      pNewNode = m_pNCManager->GetRoot(0, pParent, iLbnd, iHbnd, NULL);
+    }
   }                                                                                                                                   
   else if(iSymbol == m_pNCManager->GetStartConversionSymbol()) {                                                                  
   //  else if(iSymbol == m_pNCManager->GetSpaceSymbol()) {
