@@ -12,7 +12,7 @@
 
 // Track memory leaks on Windows to the line that new'd the memory
 #ifdef _WIN32
-#ifdef _DEBUG
+#ifdef _DEBUG_MEMLEAKS
 #define DEBUG_NEW new( _NORMAL_BLOCK, THIS_FILE, __LINE__ )
 #define new DEBUG_NEW
 #undef THIS_FILE
@@ -21,17 +21,17 @@ static char THIS_FILE[] = __FILE__;
 #endif
 
 static SModuleSettings sSettings[] = {
-  {LP_ZOOMSTEPS, T_LONG, 1, 63, 1, 1, "Zoom steps"},
-  {LP_RIGHTZOOM, T_LONG, 1024, 10240, 1024, 1024, "Right zoom"},
-  {LP_B, T_LONG, 2, 10, 1, 1, "Number of boxes"},
-  {LP_S, T_LONG, 0, 256, 1, 1, "Safety margin"},
-  {LP_R, T_LONG, -400, 400, 1, 10, "Box non-uniformity"},
-  {BP_GLOBAL_KEYBOARD, T_BOOL, -1, -1, -1, -1, "Global keyboard grab"}
+  {LP_ZOOMSTEPS, T_LONG, 1, 63, 1, 1, _("Zoom steps")},
+  {LP_RIGHTZOOM, T_LONG, 1024, 10240, 1024, 1024, _("Right zoom")},
+  {LP_B, T_LONG, 2, 10, 1, 1, _("Number of boxes")},
+  {LP_S, T_LONG, 0, 256, 1, 1, _("Safety margin")},
+  {LP_R, T_LONG, -400, 400, 1, 10, _("Box non-uniformity")},
+  {BP_GLOBAL_KEYBOARD, T_BOOL, -1, -1, -1, -1, _("Global keyboard grab")}
 };
 
 // FIXME - should compass mode be made a separate class?
 
-CDasherButtons::CDasherButtons(Dasher::CEventHandler * pEventHandler, CSettingsStore *pSettingsStore, CDasherInterfaceBase *pInterface, int iNumBoxes, int iStyle, bool bMenu, long long int iID, const char *szName)
+CDasherButtons::CDasherButtons(Dasher::CEventHandler * pEventHandler, CSettingsStore *pSettingsStore, CDasherInterfaceBase *pInterface, int iNumBoxes, int iStyle, bool bMenu, ModuleID_t iID, const char *szName)
   : CInputFilter(pEventHandler, pSettingsStore, pInterface, iID, 1, szName) {
 
   m_pBoxes = 0;
@@ -311,22 +311,22 @@ bool CDasherButtons::DecorateView(CDasherView *pView) {
   }
   else if(m_iStyle == 3) {
     if(m_iLastBox == 1) {
-      pView->NewDrawGoTo(m_pBoxes[2].iDisplayTop, m_pBoxes[2].iDisplayBottom, false);
-      pView->NewDrawGoTo(m_pBoxes[1].iDisplayTop, m_pBoxes[3].iDisplayBottom, false);
-      pView->NewDrawGoTo(m_pBoxes[4].iDisplayTop, m_pBoxes[4].iDisplayBottom, false);
+      NewDrawGoTo(pView, m_pBoxes[2].iDisplayTop, m_pBoxes[2].iDisplayBottom, false);
+      NewDrawGoTo(pView, m_pBoxes[1].iDisplayTop, m_pBoxes[3].iDisplayBottom, false);
+      NewDrawGoTo(pView, m_pBoxes[4].iDisplayTop, m_pBoxes[4].iDisplayBottom, false);
     }
     else {
-      pView->NewDrawGoTo(m_pBoxes[0].iDisplayTop, m_pBoxes[0].iDisplayBottom, false);
-      pView->NewDrawGoTo(m_pBoxes[3].iDisplayTop, m_pBoxes[1].iDisplayBottom, false);
-      pView->NewDrawGoTo(m_pBoxes[4].iDisplayTop, m_pBoxes[4].iDisplayBottom, false);
+      NewDrawGoTo(pView, m_pBoxes[0].iDisplayTop, m_pBoxes[0].iDisplayBottom, false);
+      NewDrawGoTo(pView, m_pBoxes[3].iDisplayTop, m_pBoxes[1].iDisplayBottom, false);
+      NewDrawGoTo(pView, m_pBoxes[4].iDisplayTop, m_pBoxes[4].iDisplayBottom, false);
     }
   }
   else {
     for(int i(0); i < m_iNumBoxes; ++i) {
       if(i != iActiveBox)
-	pView->NewDrawGoTo(m_pBoxes[i].iDisplayTop, m_pBoxes[i].iDisplayBottom, false);
+	NewDrawGoTo(pView, m_pBoxes[i].iDisplayTop, m_pBoxes[i].iDisplayBottom, false);
     }
-    pView->NewDrawGoTo(m_pBoxes[iActiveBox].iDisplayTop, m_pBoxes[iActiveBox].iDisplayBottom, m_bMenu || m_bHighlight);
+    NewDrawGoTo(pView, m_pBoxes[iActiveBox].iDisplayTop, m_pBoxes[iActiveBox].iDisplayBottom, m_bMenu || m_bHighlight);
   }
 
   bool bRV(m_bDecorationChanged);
@@ -434,3 +434,28 @@ bool CDasherButtons::GetSettings(SModuleSettings **pSettings, int *iCount) {
 
   return true;
 };
+
+void CDasherButtons::NewDrawGoTo(CDasherView *pView, myint iDasherMin, myint iDasherMax, bool bActive) {
+   myint iHeight(iDasherMax - iDasherMin);
+
+   int iColour;
+   int iWidth;
+
+   if(bActive) {
+     iColour = 1;
+     iWidth = 3;
+   }
+   else {
+     iColour = 2;
+     iWidth = 1;
+   }
+
+   CDasherScreen::point p[4];
+
+   pView->Dasher2Screen( 0, iDasherMin, p[0].x, p[0].y);
+   pView->Dasher2Screen( iHeight, iDasherMin, p[1].x, p[1].y);
+   pView->Dasher2Screen( iHeight, iDasherMax, p[2].x, p[2].y);
+   pView->Dasher2Screen( 0, iDasherMax, p[3].x, p[3].y);
+
+   pView->Screen()->Polyline(p, 4, iWidth, iColour);
+}
