@@ -209,6 +209,8 @@ void CDasherModel::RecursiveMakeRoot(CDasherNode *pNewRoot) {
 void CDasherModel::RebuildAroundNode(CDasherNode *pNode) {
   DASHER_ASSERT(pNode != NULL);
 
+  CDasherNode *pNodeOrig = pNode;
+
   while(pNode->GetFlag(NF_SUBNODE))
     pNode = pNode->Parent();
 
@@ -218,6 +220,8 @@ void CDasherModel::RebuildAroundNode(CDasherNode *pNode) {
   m_Root->Delete_children();
 
   m_Root->m_pNodeManager->PopulateChildren(m_Root);
+
+  m_pLastOutput = m_Root;
 }
 
 // TODO: Need to make this do the right thing with subnodes
@@ -634,9 +638,9 @@ void CDasherModel::HandleOutput(CDasherNode *pNewNode, CDasherNode *pOldNode, Da
   DASHER_ASSERT(pNewNode != NULL);
   //  DASHER_ASSERT(pOldNode != NULL);
   
-//   if(pNewNode != pOldNode)
-//     std::cout << "HandleOutput: " << pOldNode << " => " << pNewNode << std::endl;
-
+  //if(pNewNode != m_pLastOutput)
+  //  std::cout << "HandleOutput: " << pOldNode << " => " << pNewNode << std::endl;
+  
   if(pNewNode != m_pLastOutput)
     DeleteCharacters(pNewNode, m_pLastOutput, pNumDeleted);
   
@@ -682,8 +686,11 @@ bool CDasherModel::DeleteCharacters(CDasherNode *newnode, CDasherNode *oldnode,
 
     oldnode->m_pNodeManager->Undo(oldnode);
     oldnode->Parent()->m_pNodeManager->Enter(oldnode->Parent());
-    if (pNumDeleted != NULL)
-      (*pNumDeleted)++;
+
+    // TODO: This is completely the wrong place to trap output
+    if(pNumDeleted != NULL)
+      (*pNumDeleted) += oldnode->m_iNumSymbols;
+
     oldnode->SetFlag(NF_SEEN, false);
 
     if(oldnode->Parent() != newnode)
@@ -712,7 +719,8 @@ bool CDasherModel::DeleteCharacters(CDasherNode *newnode, CDasherNode *oldnode,
 	oldnode->Parent()->m_pNodeManager->Enter(oldnode->Parent());
 
       if (pNumDeleted != NULL)
-	(*pNumDeleted)++;
+	(*pNumDeleted) += oldnode->m_iNumSymbols;
+
       oldnode = oldnode->Parent();
       if(oldnode == NULL) {
         return false;
