@@ -25,7 +25,7 @@ using namespace Dasher;
 
 // Track memory leaks on Windows to the line that new'd the memory
 #ifdef _WIN32
-#ifdef _DEBUG
+#ifdef _DEBUG_MEMLEAKS
 #define DEBUG_NEW new( _NORMAL_BLOCK, THIS_FILE, __LINE__ )
 #define new DEBUG_NEW
 #undef THIS_FILE
@@ -33,6 +33,8 @@ static char THIS_FILE[] = __FILE__;
 #endif
 #endif
 
+static bool g_bDebug = false;
+
 // FIXME - quite a lot of the code here probably should be moved to
 // the parent class (DasherView). I think we really should make the
 // parent class less general - we're probably not going to implement
@@ -97,6 +99,7 @@ void CDasherViewSquare::RenderNodes(CDasherNode *pRoot, myint iRootMin, myint iR
   myint iDasherMaxY;
   VisibleRegion(iDasherMinX, iDasherMinY, iDasherMaxX, iDasherMaxY);
   //
+
   screenint iScreenLeft;
   screenint iScreenTop;
   screenint iScreenRight;
@@ -105,6 +108,8 @@ void CDasherViewSquare::RenderNodes(CDasherNode *pRoot, myint iRootMin, myint iR
   Dasher2Screen(iRootMax-iRootMin, iRootMin, iScreenLeft, iScreenTop);
   Dasher2Screen(0, iRootMax, iScreenRight, iScreenBottom);
 
+
+
   //ifiScreenTop < 0)
   //  iScreenTop = 0;
 
@@ -120,20 +125,22 @@ void CDasherViewSquare::RenderNodes(CDasherNode *pRoot, myint iRootMin, myint iR
 
   // Blank the regoin around the root node:
   
-  //if(iRootMin > iDasherMinY)
-  //  DasherDrawRectangle(iDasherMaxX, iDasherMinY, iDasherMinX, iRootMin, 0, 0, Nodes1, false,true, 1);
+  if(iRootMin > iDasherMinY)
+    DasherDrawRectangle(iDasherMaxX, iDasherMinY, iDasherMinX, iRootMin, 0, 0, Nodes1, false,true, 1);
   
-  if(iScreenTop > 0)
-    Screen()->DrawRectangle(0, 0, Screen()->GetWidth(), iScreenTop, 0, -1, Nodes1, false, true, 1);
+  //if(iScreenTop > 0)
+  //  Screen()->DrawRectangle(0, 0, Screen()->GetWidth(), iScreenTop, 0, -1, Nodes1, false, true, 1);
 
-  //if(iRootMax < iDasherMaxY)
-  //  DasherDrawRectangle(iDasherMaxX, iRootMax, iDasherMinX, iDasherMaxY, 0, 0, Nodes1, false,true, 1);
+  if(iRootMax < iDasherMaxY)
+    DasherDrawRectangle(iDasherMaxX, iRootMax, iDasherMinX, iDasherMaxY, 0, 0, Nodes1, false,true, 1);
 
-  if(iScreenBottom <= Screen()->GetHeight())
-    Screen()->DrawRectangle(0, iScreenBottom, Screen()->GetWidth(), Screen()->GetHeight(), 0, -1, Nodes1, false, true, 1);
+  //if(iScreenBottom <= Screen()->GetHeight())
+  // Screen()->DrawRectangle(0, iScreenBottom, Screen()->GetWidth(), Screen()->GetHeight(), 0, -1, Nodes1, false, true, 1);
 
-//  DasherDrawRectangle(0, iDasherMinY, iDasherMinX, iDasherMaxY, 0, 4, Nodes1, false,true, 1);
-  Screen()->DrawRectangle(iScreenRight, iScreenTop, Screen()->GetWidth(), iScreenBottom, 0, -1, Nodes1, false, true, 1);
+  DasherDrawRectangle(0, iDasherMinY, iDasherMinX, iDasherMaxY, 0, 4, Nodes1, false,true, 1);
+  //  Screen()->DrawRectangle(iScreenRight, std::max(0, (int)iScreenTop),
+  //		  Screen()->GetWidth(), std::min(Screen()->GetHeight(), (int)iScreenBottom), 
+  //		  0, -1, Nodes1, false, true, 1);
 
   // Render the root node (and children)
   RecursiveRender(pRoot, iRootMin, iRootMax, iDasherMaxX, vNodeList, vDeleteList, iGamePointer,true,iDasherMaxX,0,0);
@@ -145,7 +152,7 @@ void CDasherViewSquare::RenderNodes(CDasherNode *pRoot, myint iRootMin, myint iR
   Crosshair((myint)GetLongParameter(LP_OX));
 }
 
-int CDasherViewSquare::RecursiveRender(CDasherNode *pRender, myint y1, myint y2, int mostleft, std::vector<CDasherNode *> &vNodeList, std::vector<CDasherNode *> &vDeleteList, myint *iGamePointer, bool bDraw,myint parent_width,int parent_color, int iDepth) {
+bool CDasherViewSquare::RecursiveRender(CDasherNode *pRender, myint y1, myint y2, int mostleft, std::vector<CDasherNode *> &vNodeList, std::vector<CDasherNode *> &vDeleteList, myint *iGamePointer, bool bDraw,myint parent_width,int parent_color, int iDepth) {
   DASHER_ASSERT_VALIDPTR_RW(pRender);
 
 //   if(iDepth == 2)
@@ -189,7 +196,7 @@ int CDasherViewSquare::RecursiveRender(CDasherNode *pRender, myint y1, myint y2,
 
     vDeleteList.push_back(pRender);
     pRender->SetFlag(NF_ALIVE, false);
-    return 0;
+    return false;
   }
 
   // Set the NF_SUPER flag if this node entirely frames the visual
@@ -208,10 +215,9 @@ int CDasherViewSquare::RecursiveRender(CDasherNode *pRender, myint y1, myint y2,
  
   // If there are no children then we still need to render the parent
   if(pRender->ChildCount() == 0) {
-    if(iDepth == 1)
-      RenderNodePartFast(pRender->GetDisplayInfo()->iColour, y1, y2, mostleft, pRender->GetDisplayInfo()->strDisplayText, pRender->GetDisplayInfo()->bShove,y2-y1);
+    RenderNodePartFast(pRender->GetDisplayInfo()->iColour, y1, y2, mostleft, pRender->GetDisplayInfo()->strDisplayText, pRender->GetDisplayInfo()->bShove,y2-y1);
     vNodeList.push_back(pRender);
-    return 1;  // CHANGED BY IGNAS. I return 1 when the child was rendered and in this case the 
+    return true;  // CHANGED BY IGNAS. I return 1 when the child was rendered and in this case the 
     //child was rendered.
   }
 
@@ -302,7 +308,7 @@ int CDasherViewSquare::RecursiveRender(CDasherNode *pRender, myint y1, myint y2,
   //  if(iDepth == 2)
     //    std::cout << "done." << std::endl;
   
-  return 1;
+  return true;
 }
 
 
@@ -362,21 +368,30 @@ int CDasherViewSquare::RenderNodeOutlineFast(const int Color, myint y1, myint y2
   if((y1 > iDasherMaxY) || (y2 < iDasherMinY)){
     return 0;                   // We're entirely off screen, so don't render.
   }
- if(!GetBoolParameter(BP_OUTLINE_MODE))
-	  return 1;
+
+  // TODO: This should be earlier?
+  if(!GetBoolParameter(BP_OUTLINE_MODE))
+    return 1;
+
   myint iDasherSize(y2 - y1);
+ 
 
-  // FIXME - get rid of pointless assignment below
 
-  int iTruncation(GetLongParameter(LP_TRUNCATION));     // Trucation farction times 100;
-  //  int iTruncationType(GetLongParameter(LP_TRUNCATIONTYPE));
+  //  std::cout << std::min(iDasherSize,iDasherMaxX) << " " << std::min(y2,iDasherMaxY) << " 0 " << std::max(y1,iDasherMinY) << std::endl;
 
-  if(iTruncation == 0) {        // Regular squares
-    DasherDrawRectangle(std::min(iDasherSize,iDasherMaxX), std::min(y2,iDasherMaxY),0, std::max(y1,iDasherMinY), Color, -1, Nodes1, true,false, 1);
-  }
-  else { 
-    // TODO: Put something back here?
-  }
+  DasherDrawRectangle(0, std::min(y1,iDasherMaxY),std::min(iDasherSize,iDasherMaxX), std::max(y2,iDasherMinY), Color, -1, Nodes1, true,false, 1);
+
+//   // FIXME - get rid of pointless assignment below
+
+//   int iTruncation(GetLongParameter(LP_TRUNCATION));     // Trucation farction times 100;
+//   //  int iTruncationType(GetLongParameter(LP_TRUNCATIONTYPE));
+
+//   if(iTruncation == 0) {        // Regular squares
+
+//   }
+//   else { 
+//     // TODO: Put something back here?
+//   }
 
   return 1;
 }
@@ -664,10 +679,12 @@ void CDasherViewSquare::Screen2Dasher(screenint iInputX, screenint iInputY, myin
   screenint iScreenWidth = Screen()->GetWidth();
   screenint iScreenHeight = Screen()->GetHeight();
 
+  // TODO: Is this used any more?
   if( b1D ) { // Special case for 1D mode...
-    iDasherX = iInputX * iDasherWidth / iScreenWidth;
-    iDasherY = iInputY * iDasherHeight / iScreenHeight;
-    return;
+    DASHER_ASSERT(false);
+    //    iDasherX = iInputX * iDasherWidth / iScreenWidth;
+    // iDasherY = iInputY * iDasherHeight / iScreenHeight;
+    //return;
   }
 
   int eOrientation(GetLongParameter(LP_REAL_ORIENTATION));
@@ -699,10 +716,11 @@ void CDasherViewSquare::Screen2Dasher(screenint iInputX, screenint iInputY, myin
 #ifndef WITH_MAEMO
   // FIXME - disabled to avoid floating point
   if( bNonlinearity ) {
-  iDasherX = myint(ixmap(iDasherX / static_cast < double >(GetLongParameter(LP_MAX_Y))) * (myint)GetLongParameter(LP_MAX_Y));
-  iDasherY = m_ymap.unmap(iDasherY);
+    iDasherX = myint(ixmap(iDasherX / static_cast < double >(GetLongParameter(LP_MAX_Y))) * (myint)GetLongParameter(LP_MAX_Y));
+    iDasherY = m_ymap.unmap(iDasherY);
   }
 #endif
+  
 }
 
 void CDasherViewSquare::SetScaleFactor( void )
@@ -748,8 +766,34 @@ void CDasherViewSquare::GetScaleFactor( int eOrientation, myint *iScaleFactorX,
   }
 }
 
-/// Convert dasher co-ordinates to screen co-ordinates
+
+inline myint CDasherViewSquare::CustomIDiv(myint iNumerator, myint iDenominator) { 
+  // Integer division rounding away from zero
   
+#ifdef _WIN32
+  myint quot = iNumerator / iDenominator;
+  myint rem = (int64)iNumerator % (int64)iDenominator;
+
+  if(rem < 0)
+    return quot - 1;
+  else if (rem > 0)
+    return quot + 1;
+  else
+    return quot;
+#else
+  lldiv_t res = __gnu_cxx::lldiv(iNumerator, iDenominator);
+  
+  if(res.rem < 0)
+    return res.quot - 1;
+  else if (res.rem > 0)
+    return res.quot + 1;
+  else
+    return res.quot;
+#endif
+
+  // return (iNumerator + iDenominator - 1) / iDenominator;
+}
+
 void CDasherViewSquare::Dasher2Screen(myint iDasherX, myint iDasherY, screenint &iScreenX, screenint &iScreenY) {
 
   // Apply the nonlinearities
@@ -760,6 +804,7 @@ void CDasherViewSquare::Dasher2Screen(myint iDasherX, myint iDasherY, screenint
   iDasherY = m_ymap.map(iDasherY);
 #endif
 
+
   // Things we're likely to need:
 
   myint iDasherWidth = (myint)GetLongParameter(LP_MAX_Y);
@@ -775,22 +820,35 @@ void CDasherViewSquare::Dasher2Screen(myint iDasherX, myint iDasherY, screenint
 
   GetScaleFactor( eOrientation, &iScaleFactorX, &iScaleFactorY);
 
+
+  // Note that integer division is rounded *away* from zero here to
+  // enesure that this really is the inverse of the map the other way
+  // around.
+
   switch( eOrientation ) {
   case Dasher::Opts::LeftToRight:
-    iScreenX = screenint(iScreenWidth / 2 - ( iDasherX - iDasherWidth / 2 ) * iScaleFactorX / m_iScalingFactor);
-    iScreenY = screenint(iScreenHeight / 2 + ( iDasherY - iDasherHeight / 2 ) * iScaleFactorY / m_iScalingFactor);
+    iScreenX = screenint(iScreenWidth / 2 - 
+			 CustomIDiv((( iDasherX - iDasherWidth / 2 ) * iScaleFactorX), m_iScalingFactor));
+    iScreenY = screenint(iScreenHeight / 2 +
+			 CustomIDiv(( iDasherY - iDasherHeight / 2 ) * iScaleFactorY, m_iScalingFactor));
     break;
   case Dasher::Opts::RightToLeft:
-    iScreenX = screenint(iScreenWidth / 2 + ( iDasherX - iDasherWidth / 2 ) * iScaleFactorX / m_iScalingFactor);
-    iScreenY = screenint(iScreenHeight / 2 + ( iDasherY - iDasherHeight / 2 ) * iScaleFactorY / m_iScalingFactor);
+    iScreenX = screenint(iScreenWidth / 2 + 
+			 CustomIDiv(( iDasherX - iDasherWidth / 2 ) * iScaleFactorX, m_iScalingFactor));
+    iScreenY = screenint(iScreenHeight / 2 + 
+			 CustomIDiv(( iDasherY - iDasherHeight / 2 ) * iScaleFactorY, m_iScalingFactor));
     break;
   case Dasher::Opts::TopToBottom:
-    iScreenX = screenint(iScreenWidth / 2 + ( iDasherY - iDasherHeight / 2 ) * iScaleFactorX / m_iScalingFactor);
-    iScreenY = screenint(iScreenHeight / 2 - ( iDasherX - iDasherWidth / 2 ) * iScaleFactorY / m_iScalingFactor);
+    iScreenX = screenint(iScreenWidth / 2 + 
+			 CustomIDiv(( iDasherY - iDasherHeight / 2 ) * iScaleFactorX, m_iScalingFactor));
+    iScreenY = screenint(iScreenHeight / 2 - 
+			 CustomIDiv(( iDasherX - iDasherWidth / 2 ) * iScaleFactorY, m_iScalingFactor));
     break;
   case Dasher::Opts::BottomToTop:
-    iScreenX = screenint(iScreenWidth / 2 + ( iDasherY - iDasherHeight / 2 ) * iScaleFactorX / m_iScalingFactor);
-    iScreenY = screenint(iScreenHeight / 2 + ( iDasherX - iDasherWidth / 2 ) * iScaleFactorY / m_iScalingFactor);
+    iScreenX = screenint(iScreenWidth / 2 + 
+			 CustomIDiv(( iDasherY - iDasherHeight / 2 ) * iScaleFactorX, m_iScalingFactor));
+    iScreenY = screenint(iScreenHeight / 2 + 
+			 CustomIDiv(( iDasherX - iDasherWidth / 2 ) * iScaleFactorY, m_iScalingFactor));
     break;
   }
 }
