@@ -5,9 +5,11 @@
 #include "AutoSpeedControl.h"
 #include "StartHandler.h"
 
+/// \ingroup InputFilter
+/// @{
 class CDefaultFilter : public CInputFilter {
  public:
-  CDefaultFilter(Dasher::CEventHandler * pEventHandler, CSettingsStore *pSettingsStore, CDasherInterfaceBase *pInterface, CDasherModel *m_pDasherModel, long long int iID, const char *szName);
+  CDefaultFilter(Dasher::CEventHandler * pEventHandler, CSettingsStore *pSettingsStore, CDasherInterfaceBase *pInterface, CDasherModel *m_pDasherModel, ModuleID_t iID, const char *szName);
   ~CDefaultFilter();
 
   virtual void HandleEvent(Dasher::CEvent * pEvent);
@@ -28,5 +30,6 @@ class CDefaultFilter : public CInputFilter {
   CAutoSpeedControl *m_pAutoSpeedControl;
   CStartHandler *m_pStartHandler;
 };
+/// @}
 
 #endif
