@@ -21,8 +21,14 @@ class CInputFilter : public CDasherModule {
 
   virtual void HandleEvent(Dasher::CEvent * pEvent) {};
   virtual bool DecorateView(CDasherView *pView) { return false; };
-  virtual void KeyDown(int Time, int iId, CDasherModel *pModel, CUserLogBase *pUserLog) {};
-  virtual void KeyUp(int Time, int iId, CDasherModel *pModel) {};
+
+  virtual void KeyDown(int Time, int iId, CDasherModel *pModel, CUserLogBase *pUserLog, bool bPos, int iX, int iY) {
+    KeyDown(Time, iId, pModel, pUserLog);
+  };
+  virtual void KeyUp(int Time, int iId, CDasherModel *pModel, bool bPos, int iX, int iY) {
+    KeyUp(Time, iId, pModel);
+  };
+
   virtual bool Timer(int Time, CDasherView *m_pDasherView, CDasherModel *m_pDasherModel, Dasher::VECTOR_SYMBOL_PROB *pAdded, int *pNumDeleted) { return false; };
 
   virtual void Activate() {};
@@ -34,6 +40,10 @@ class CInputFilter : public CDasherModule {
   
  protected:
   CDasherInterfaceBase *m_pInterface;
+
+ private:
+  virtual void KeyDown(int Time, int iId, CDasherModel *pModel, CUserLogBase *pUserLog) {};
+  virtual void KeyUp(int Time, int iId, CDasherModel *pModel) {};
 };
 /// @}
 
