@@ -4,7 +4,6 @@
 #include "LanguageModelling/WordLanguageModel.h"
 #include "LanguageModelling/DictLanguageModel.h"
 #include "LanguageModelling/MixtureLanguageModel.h"
-//#include "LanguageModelling/CTWLanguageModel.h"
 #include "NodeCreationManager.h"
 
 CNodeCreationManager::CNodeCreationManager(Dasher::CDasherInterfaceBase *pInterface, Dasher::CEventHandler *pEventHandler, CSettingsStore *pSettingsStore, bool bGameMode, std::string strGameModeText, Dasher::CAlphIO *pAlphIO) : CDasherComponent(pEventHandler, pSettingsStore) {
@@ -15,8 +14,12 @@ CNodeCreationManager::CNodeCreationManager(Dasher::CDasherInterfaceBase *pInterf
  
   int iConversionID(m_pAlphabetManagerFactory->GetConversionID());
 
+#ifndef _WIN32_WCE
   m_pControlManagerFactory = new CControlManagerFactory(this);
-  m_pConversionManagerFactory = new CConversionManagerFactory(pEventHandler, pSettingsStore, this, iConversionID, pAlphIO);
+#else
+  m_pControlManagerFactory = 0;
+#endif
+  m_pConversionManagerFactory = new CConversionManagerFactory(pEventHandler, pSettingsStore, this, iConversionID, pAlphIO, m_pAlphabet);
 }
 
 CNodeCreationManager::~CNodeCreationManager() {
@@ -36,7 +39,10 @@ CDasherNode *CNodeCreationManager::GetRoot(int iType, Dasher::CDasherNode *pPare
   case 0:
     return m_pAlphabetManagerFactory->GetRoot(pParent, iLower, iUpper, pUserData);
   case 1:
-    return m_pControlManagerFactory->GetRoot(pParent, iLower, iUpper, pUserData);
+    if(m_pControlManagerFactory)
+      return m_pControlManagerFactory->GetRoot(pParent, iLower, iUpper, pUserData);
+    else
+      return NULL;
   case 2:
     if(m_pConversionManagerFactory)
       return m_pConversionManagerFactory->GetRoot(pParent, iLower, iUpper, pUserData);
@@ -63,47 +69,46 @@ void CNodeCreationManager::GetProbs(CLanguageModel::Context context, std::vector
   }
 
   // TODO - sort out size of control node - for the timebeing I'll fix the control node at 5%
+  // TODO: New method (see commented code) has been removed as it wasn' working.
 
   int uniform_add;
   int nonuniform_norm;
   int control_space = 0;
   int uniform = GetLongParameter(LP_UNIFORM);
 
-  // TODO: Sort this out
+   if(!GetBoolParameter(BP_CONTROL_MODE)) {
+     control_space = 0;
+     uniform_add = ((iNorm * uniform) / 1000) / (iSymbols - 2);  // Subtract 2 from no symbols to lose control/root nodes
+     nonuniform_norm = iNorm - (iSymbols - 2) * uniform_add;
+   }
+   else {
+     control_space = int (iNorm * 0.05);
+     uniform_add = (((iNorm - control_space) * uniform / 1000) / (iSymbols - 2));        // Subtract 2 from no symbols to lose control/root nodes
+     nonuniform_norm = iNorm - control_space - (iSymbols - 2) * uniform_add;
+   }
+   
+   //  m_pLanguageModel->GetProbs(context, Probs, iNorm, ((iNorm * uniform) / 1000));
+   m_pLanguageModel->GetProbs(context, Probs, iNorm, 0);
 
-  if(!GetBoolParameter(BP_CONTROL_MODE)) {
-    control_space = 0;
-    uniform_add = ((iNorm * uniform) / 1000) / (iSymbols - 2);  // Subtract 2 from no symbols to lose control/root nodes
-    nonuniform_norm = iNorm - (iSymbols - 2) * uniform_add;
-  }
-  else {
-    control_space = int (iNorm * 0.05);
-    uniform_add = (((iNorm - control_space) * uniform / 1000) / (iSymbols - 2));        // Subtract 2 from no symbols to lose control/root nodes
-    nonuniform_norm = iNorm - control_space - (iSymbols - 2) * uniform_add;
-  }
+   // #if _DEBUG
+   //int iTotal = 0;
+   //for(int k = 0; k < Probs.size(); ++k)
+     //     iTotal += Probs[k];
+   //   DASHER_ASSERT(iTotal == nonuniform_norm);
+// #endif
 
-  //m_pLanguageModel->GetProbs(context, Probs, iNorm, ((iNorm * uniform) / 1000));
-  m_pLanguageModel->GetProbs(context, Probs, iNorm, 0);
+//   //  Probs.insert(Probs.begin(), 0);
+
+   for(unsigned int k(1); k < Probs.size(); ++k)
+     Probs[k] += uniform_add;
+
+  Probs.push_back(control_space);
 
 #if _DEBUG
   int iTotal = 0;
   for(int k = 0; k < Probs.size(); ++k)
     iTotal += Probs[k];
-  DASHER_ASSERT(iTotal == nonuniform_norm);
-#endif
-
-    //Probs.insert(Probs.begin(), 0);
-
-  for(unsigned int k(1); k < Probs.size(); ++k)
-    Probs[k] += uniform_add;
-
-  Probs.push_back(control_space);
-
-#if _DEBUG
-  iTotal = 0;
-  for(int k = 0; k < Probs.size(); ++k)
-    iTotal += Probs[k];
-//      DASHER_ASSERT(iTotal == iNorm);
+  DASHER_ASSERT(iTotal == iNorm);
 #endif
 
 }
