@@ -19,6 +19,10 @@
 #endif
 #include "dasher_main.h"
 
+#include "DasherAppSettings.h"
+#include "dasher_editor_internal.h"
+#include "dasher_editor_external.h"
+
 /* Static instance of singleton, USE SPARINGLY */
 static DasherMain *g_pDasherMain = NULL; 
 
@@ -113,7 +117,10 @@ static DasherMenuCommand MenuCommands[] = {
   {NULL, "tb_command_saveas", "saveas"},
   {NULL, "tb_command_cut", "cut"},
   {NULL, "tb_command_copy", "copy"},
-  {NULL, "tb_command_paste", "paste"}
+  {NULL, "tb_command_paste", "paste"},
+  {NULL, "tb_command_preferences", "preferences"},
+  {NULL, "tb_command_help", "help"},
+  {NULL, "tb_command_quit", "quit"}
 };
 
 G_DEFINE_TYPE(DasherMain, dasher_main, G_TYPE_OBJECT);
@@ -124,7 +131,7 @@ static void dasher_main_finalize(GObject *pObject);
 static void dasher_main_setup_window_state(DasherMain *pSelf);
 static void dasher_main_setup_window_style(DasherMain *pSelf);
 static void dasher_main_setup_internal_layout(DasherMain *pSelf);
-static void dasher_main_refresh_font(DasherMain *pSelf);
+//static void dasher_main_refresh_font(DasherMain *pSelf);
 static void dasher_main_set_filename(DasherMain *pSelf);
 
 /* ... Table based menu/toolbar commands */
@@ -163,6 +170,7 @@ gboolean grab_focus();
 
 /* Callback functions */
 extern "C" GtkWidget *create_dasher_control(gchar *szName, gchar *szString1, gchar *szString2, gint iInt1, gint iInt2);
+extern "C" GtkWidget *create_dasher_editor(gchar *szName, gchar *szString1, gchar *szString2, gint iInt1, gint iInt2);
 
 /* ... Message handling from main window widgets */
 extern "C" gboolean dasher_main_cb_menu_command(GtkWidget *pWidget, gpointer pUserData);
@@ -209,9 +217,6 @@ static void
 dasher_main_init(DasherMain *pDasherMain) {
   DasherMainPrivate *pPrivate = DASHER_MAIN_GET_PRIVATE(pDasherMain);
   
-  /* TODO: define log domain */
-  g_debug("Initialising DasherMain");
-
   pPrivate->pAppSettings = NULL;
   pPrivate->pEditor = NULL;
   pPrivate->pPreferencesDialogue = NULL;
@@ -223,8 +228,6 @@ dasher_main_init(DasherMain *pDasherMain) {
 
 static void
 dasher_main_finalize(GObject *pObject) {
-  /* TODO: Need a general overview of class finalisation */
-  g_debug("Finalizing DasherMain");
 
   DasherMain *pDasherMain = DASHER_MAIN(pObject);
   DasherMainPrivate *pPrivate = DASHER_MAIN_GET_PRIVATE(pDasherMain);
@@ -232,8 +235,8 @@ dasher_main_finalize(GObject *pObject) {
   dasher_main_save_state(pDasherMain);
 
   /* TODO: Does unref really do the right thing - check the whole ref counting situation */
-  if(pPrivate->pEditor)
-    g_object_unref(pPrivate->pEditor);
+  //  if(pPrivate->pEditor)
+  //  g_object_unref(pPrivate->pEditor);
 
   if(pPrivate->pPreferencesDialogue)
     g_object_unref(pPrivate->pPreferencesDialogue);
@@ -253,6 +256,8 @@ dasher_main_new(int *argc, char ***argv, SCommandLine *pCommandLine) {
     return g_pDasherMain;
   else {
     DasherMain *pDasherMain = (DasherMain *)(g_object_new(dasher_main_get_type(), NULL));
+    g_pDasherMain = pDasherMain;
+
     DasherMainPrivate *pPrivate = DASHER_MAIN_GET_PRIVATE(pDasherMain);
 
     /* Create the app settings object */
@@ -277,12 +282,52 @@ dasher_main_new(int *argc, char ***argv, SCommandLine *pCommandLine) {
       }
     }
     else { 
-      dasher_app_settings_set_long(pPrivate->pAppSettings, APP_LP_STYLE, 0);
+      // Direct entry is now the default
+      dasher_app_settings_set_long(pPrivate->pAppSettings, APP_LP_STYLE, 2);
     }
 
     dasher_main_load_interface(pDasherMain);
 
     dasher_app_settings_set_widget(pPrivate->pAppSettings, GTK_DASHER_CONTROL(pPrivate->pDasherWidget));
+
+
+    /* TODO: This parsing code should really be tidied up */
+    if(pCommandLine && pCommandLine->szOptions) {
+      gchar **pszOptionTerms;
+      pszOptionTerms = g_strsplit(pCommandLine->szOptions, ",", 0);
+
+      gchar **pszCurrent = pszOptionTerms;
+
+      while(*pszCurrent) {
+	gchar *szJoin = g_strrstr(*pszCurrent, "=");
+
+	if(szJoin) {
+	  int iLength = szJoin - *pszCurrent;
+	  
+	  gchar *szKey = g_new(gchar, iLength + 1);
+	  memcpy(szKey, *pszCurrent, iLength);
+	  szKey[iLength] = '\0';
+	  
+	  dasher_app_settings_cl_set(pPrivate->pAppSettings, szKey, szJoin + 1);
+	  
+	  g_free(szKey);
+	}
+	else {
+	  g_error("Invalid option string specified");
+	}
+
+	++pszCurrent;
+      }
+
+      g_strfreev(pszOptionTerms);
+    }
+    /* --- */
+
+
+
+    dasher_editor_initialise(pPrivate->pEditor, pPrivate->pAppSettings, pDasherMain, pPrivate->pGladeXML, NULL);
+
+
     dasher_main_setup_window(pDasherMain);
 
     /* Create the editor */
@@ -302,13 +347,18 @@ dasher_main_new(int *argc, char ***argv, SCommandLine *pCommandLine) {
       }
     }
 
-    pPrivate->pEditor = dasher_editor_new(pPrivate->pAppSettings, pDasherMain, pPrivate->pGladeXML, szFullPath);
+    // TODO: Fix this
+//     pPrivate->pEditor = GTK_EDITOR(
+
+
+// dasher_editor_initialise(pPrivate->pAppSettings, pDasherMain, pPrivate->pGladeXML, szFullPath);
 
     g_free(szFullPath);
 
-    g_signal_connect(pPrivate->pEditor, "filename_changed", G_CALLBACK(dasher_main_cb_filename_changed), pDasherMain);
-    g_signal_connect(pPrivate->pEditor, "buffer_changed", G_CALLBACK(dasher_main_cb_buffer_changed), pDasherMain);
-    g_signal_connect(pPrivate->pEditor, "context_changed", G_CALLBACK(dasher_main_cb_context_changed), pDasherMain);
+    // TODO: Were these really needed?
+    //    g_signal_connect(pPrivate->pEditor, "filename_changed", G_CALLBACK(dasher_main_cb_filename_changed), pDasherMain);
+    //    g_signal_connect(pPrivate->pEditor, "buffer_changed", G_CALLBACK(dasher_main_cb_buffer_changed), pDasherMain);
+    //    g_signal_connect(pPrivate->pEditor, "context_changed", G_CALLBACK(dasher_main_cb_context_changed), pDasherMain);
 
     /* Create the preferences window */
     dasher_main_create_preferences(pDasherMain);
@@ -327,9 +377,6 @@ dasher_main_new(int *argc, char ***argv, SCommandLine *pCommandLine) {
 
     gtk_key_snooper_install(dasher_main_key_snooper, pDasherMain);
 
-    /* Cache a file-wide static pointer to the singleton class */
-    g_pDasherMain = pDasherMain;
-
     return pDasherMain;   
   }
 }
@@ -360,7 +407,8 @@ dasher_main_load_interface(DasherMain *pSelf) {
     szGladeFilename = PROGDATA "/dasher.compose.glade";
     break;
   case 2:
-    szGladeFilename = PROGDATA "/dasher.direct.glade";
+    //    szGladeFilename = PROGDATA "/dasher.direct.glade";
+    szGladeFilename = PROGDATA "/dasher.traditional.glade";
     break;
   case 3:
     szGladeFilename = PROGDATA "/dasher.fullscreen.glade";
@@ -491,9 +539,9 @@ dasher_main_load_interface(DasherMain *pSelf) {
 
   // TODO: Specify callbacks in glade file
   // TODO: Rationalise focus
-  g_signal_connect(G_OBJECT(pPrivate->pBufferView), "button-release-event", G_CALLBACK(take_real_focus), NULL);
-  g_signal_connect(G_OBJECT(pPrivate->pBufferView), "key-press-event", G_CALLBACK(edit_key_press), NULL);
-  g_signal_connect(G_OBJECT(pPrivate->pBufferView), "key-release-event", G_CALLBACK(edit_key_release), NULL);
+  //  g_signal_connect(G_OBJECT(pPrivate->pBufferView), "button-release-event", G_CALLBACK(take_real_focus), NULL);
+  // g_signal_connect(G_OBJECT(pPrivate->pBufferView), "key-press-event", G_CALLBACK(edit_key_press), NULL);
+  //g_signal_connect(G_OBJECT(pPrivate->pBufferView), "key-release-event", G_CALLBACK(edit_key_release), NULL);
 
   pPrivate->iAlphabetComboHandler = g_signal_connect(G_OBJECT(pPrivate->pAlphabetCombo), "changed", G_CALLBACK(alphabet_combo_changed), NULL);
   
@@ -509,8 +557,28 @@ dasher_main_load_interface(DasherMain *pSelf) {
   gtk_window_set_decorated(GTK_WINDOW(pPrivate->pMainWindow), false);
 #endif
   
+  // Hide any widgets which aren't appropriate for this mode
+  
+  if(dasher_app_settings_get_long(pPrivate->pAppSettings, APP_LP_STYLE) == 2) {
+    gtk_widget_hide(glade_xml_get_widget(pPrivate->pGladeXML, "dasher_menu_bar"));
+      
+    gtk_widget_hide(glade_xml_get_widget(pPrivate->pGladeXML, "tb_command_new"));
+    gtk_widget_hide(glade_xml_get_widget(pPrivate->pGladeXML, "tb_command_open"));
+    gtk_widget_hide(glade_xml_get_widget(pPrivate->pGladeXML, "tb_command_save"));
+    gtk_widget_hide(glade_xml_get_widget(pPrivate->pGladeXML, "tb_command_saveas"));
+    gtk_widget_hide(glade_xml_get_widget(pPrivate->pGladeXML, "separatortoolitem1"));
+    gtk_widget_hide(glade_xml_get_widget(pPrivate->pGladeXML, "tb_command_cut"));
+    gtk_widget_hide(glade_xml_get_widget(pPrivate->pGladeXML, "tb_command_copy"));
+    gtk_widget_hide(glade_xml_get_widget(pPrivate->pGladeXML, "tb_command_paste"));
+    gtk_widget_hide(glade_xml_get_widget(pPrivate->pGladeXML, "separatortoolitem2"));
+  }
+    
+  
   dasher_main_connect_menus(pSelf);
 
+
+  pPrivate->pEditor = DASHER_EDITOR(glade_xml_get_widget(pPrivate->pGladeXML, "DasherEditor"));
+  // TODO: szFullPath
   pPrivate->bWidgetsInitialised = true;
 }
 
@@ -543,9 +611,10 @@ dasher_main_handle_parameter_change(DasherMain *pSelf, int iParameter) {
     else
       gtk_widget_hide(pPrivate->pStatusControl);
     break;
-  case APP_SP_EDIT_FONT:
-    dasher_main_refresh_font(pSelf);
-    break;
+    //  case APP_SP_EDIT_FONT:
+    // TODO: Editor should handle this directly
+    //    dasher_main_refresh_font(pSelf);
+    //    break;
 #ifndef WITH_MAEMO
   case LP_MAX_BITRATE:
     gtk_spin_button_set_value(GTK_SPIN_BUTTON(pPrivate->pSpeedBox), dasher_app_settings_get_long(pPrivate->pAppSettings, LP_MAX_BITRATE) / 100.0);
@@ -584,8 +653,11 @@ dasher_main_handle_parameter_change(DasherMain *pSelf, int iParameter) {
 #endif
   }
 
-  // TODO: Pass into editor?
-  dasher_preferences_dialogue_handle_parameter_change(pPrivate->pPreferencesDialogue, iParameter);
+  if(pPrivate->pPreferencesDialogue)
+    dasher_preferences_dialogue_handle_parameter_change(pPrivate->pPreferencesDialogue, iParameter);
+
+  if(pPrivate->pEditor)
+    dasher_editor_handle_parameter_change(pPrivate->pEditor, iParameter);
 }
 
 static void 
@@ -615,6 +687,16 @@ dasher_main_load_state(DasherMain *pSelf) {
 
   pPrivate->iWidth = iWindowWidth;
   pPrivate->iHeight = iWindowHeight;
+
+
+  int iWindowX;
+  int iWindowY;
+ 
+  iWindowX = dasher_app_settings_get_long(pPrivate->pAppSettings, APP_LP_X);
+  iWindowY = dasher_app_settings_get_long(pPrivate->pAppSettings, APP_LP_Y);
+
+  gtk_window_move(GTK_WINDOW(pPrivate->pMainWindow), iWindowX, iWindowY);
+
   
   //  pPrivate->iPosition = dasher_app_settings_get_long(pPrivate->pAppSettings, APP_LP_DOCK_POSITION);
 }
@@ -644,6 +726,13 @@ dasher_main_save_state(DasherMain *pSelf) {
      dasher_app_settings_set_long(pPrivate->pAppSettings, APP_LP_SCREEN_HEIGHT_H, iWindowHeight);
    } 
 
+   int iWindowX;
+   int iWindowY;
+   gtk_window_get_position(GTK_WINDOW(pPrivate->pMainWindow), &iWindowX, &iWindowY);
+
+   dasher_app_settings_set_long(pPrivate->pAppSettings, APP_LP_X, iWindowX);
+   dasher_app_settings_set_long(pPrivate->pAppSettings, APP_LP_Y, iWindowY);
+
    //   dasher_app_settings_set_long(pPrivate->pAppSettings, APP_LP_DOCK_POSITION, pPrivate->iPosition);
 }
 
@@ -809,6 +898,9 @@ dasher_main_setup_window_style(DasherMain *pSelf) {
 
     // Refuse focus
     gtk_window_set_accept_focus(GTK_WINDOW(pPrivate->pMainWindow), false);
+
+    // Stick on all desktops
+    gtk_window_stick(GTK_WINDOW(pPrivate->pMainWindow));
     break;
   case 3:
     // Fullscreen mode - set fullscreen
@@ -838,20 +930,16 @@ dasher_main_setup_internal_layout(DasherMain *pSelf) {
       gtk_widget_hide(pPrivate->pStatusControl);
   }
 
-  dasher_main_refresh_font(pSelf);
+  //  dasher_main_refresh_font(pSelf);
 }
 
-static void 
-dasher_main_refresh_font(DasherMain *pSelf) {
-  DasherMainPrivate *pPrivate = DASHER_MAIN_GET_PRIVATE(pSelf);
+// static void 
+// dasher_main_refresh_font(DasherMain *pSelf) {
+//   DasherMainPrivate *pPrivate = DASHER_MAIN_GET_PRIVATE(pSelf);
 
-  const gchar *szFontName = dasher_app_settings_get_string(pPrivate->pAppSettings, APP_SP_EDIT_FONT);
-  PangoFontDescription *pFD = pango_font_description_from_string(szFontName);
-
-  if(strcmp(szFontName, "")) {
-    gtk_widget_modify_font(pPrivate->pBufferView, pFD);
-  }
-}
+//   dasher_editor_handle_font(pPrivate->pEditor, 
+// 			    dasher_app_settings_get_string(pPrivate->pAppSettings, APP_SP_EDIT_FONT));
+// }
 
 // TODO: Fold into setup controls?
 static void 
@@ -1017,7 +1105,8 @@ dasher_main_command_about(DasherMain *pSelf) {
 
 #if (defined GNOME_LIBS) || (GTK_CHECK_VERSION(2,6,0))
 
-  // In alphabetical order
+  // In alphabetical order - please keep this in sync with the AUTHORS
+  // file at root of the package tree
   const gchar *authors[] = {
     "Chris Ball",
     "Ignas Budvytis",
@@ -1028,7 +1117,9 @@ dasher_main_command_about(DasherMain *pSelf) {
     "Chris Hack",
     "David MacKay",
     "Iain Murray",
+    "Sega Kazue",
     "Takashi Kaburagi",
+    "Martijn van Veen",
     "Keith Vertanen",
     "Hanna Wallach",
     "David Ward",
@@ -1231,6 +1322,19 @@ create_dasher_control(gchar *szName, gchar *szString1, gchar *szString2, gint iI
   return pDasherControl;
 }
 
+extern "C" GtkWidget *
+create_dasher_editor(gchar *szName, gchar *szString1, gchar *szString2, gint iInt1, gint iInt2) {
+  g_return_val_if_fail(g_pDasherMain != NULL, NULL);
+
+  DasherMain *pDasherMain = DASHER_MAIN(g_pDasherMain);
+  DasherMainPrivate *pPrivate = DASHER_MAIN_GET_PRIVATE(pDasherMain);
+
+  if(dasher_app_settings_get_long(pPrivate->pAppSettings, APP_LP_STYLE) == 2)
+    return GTK_WIDGET(dasher_editor_external_new());
+  else
+    return GTK_WIDGET(dasher_editor_internal_new());
+}
+
 extern "C" gboolean 
 dasher_main_cb_menu_command(GtkWidget *pWidget, gpointer pUserData) {
   dasher_main_menu_command((DasherMain *)pUserData, pWidget);
@@ -1255,23 +1359,29 @@ alphabet_combo_changed(GtkWidget *pWidget, gpointer pUserData) {
 
 extern "C" void 
 dasher_main_cb_filename_changed(DasherEditor *pEditor, gpointer pUserData) {
-  dasher_main_set_filename(DASHER_MAIN(pUserData));
+  if(g_pDasherMain)
+    dasher_main_set_filename(g_pDasherMain);
 }
 
 extern "C" void 
 dasher_main_cb_buffer_changed(DasherEditor *pEditor, gpointer pUserData) {
-  DasherMain *pDasherMain = DASHER_MAIN(pUserData);
-  DasherMainPrivate *pPrivate = DASHER_MAIN_GET_PRIVATE(pDasherMain);
+  if(!g_pDasherMain)
+    return;
+
+  DasherMainPrivate *pPrivate = DASHER_MAIN_GET_PRIVATE(g_pDasherMain);
 
   gtk_dasher_control_set_buffer(GTK_DASHER_CONTROL(pPrivate->pDasherWidget), dasher_editor_get_offset(pPrivate->pEditor));
 }
 
 extern "C" void 
 dasher_main_cb_context_changed(DasherEditor *pEditor, gpointer pUserData) {
+  if(!g_pDasherMain)
+    return;
+
   if(!g_bSend)
     return;
 
-  DasherMain *pDasherMain = DASHER_MAIN(pUserData);
+  DasherMain *pDasherMain = DASHER_MAIN(g_pDasherMain);
   DasherMainPrivate *pPrivate = DASHER_MAIN_GET_PRIVATE(pDasherMain);
 
   gtk_dasher_control_set_offset(GTK_DASHER_CONTROL(pPrivate->pDasherWidget), dasher_editor_get_offset(pPrivate->pEditor));
@@ -1436,3 +1546,91 @@ dasher_main_key_snooper(GtkWidget *pWidget, GdkEventKey *pEvent, gpointer pUserD
     return FALSE;
   }
 }
+
+// Callbacks from the Dasher widget
+
+extern "C" void 
+handle_stop_event(GtkDasherControl *pDasherControl, gpointer data) {
+  if(g_pDasherMain) {
+    DasherMainPrivate *pPrivate = DASHER_MAIN_GET_PRIVATE(g_pDasherMain);
+
+    if(pPrivate->pEditor)
+      dasher_editor_handle_stop(pPrivate->pEditor);
+  }
+}
+
+extern "C" void 
+on_message(GtkDasherControl *pDasherControl, gpointer pMessageInfo, gpointer pUserData) { 
+  // TODO: I don't believe that this is widely used, but possibly need to reimplement
+
+//   if(g_pDasherMain) {
+//     DasherMainPrivate *pPrivate = DASHER_MAIN_GET_PRIVATE(g_pDasherMain);
+
+//     if(pPrivate->pEditor)
+//        dasher_editor_display_message(pPrivate->pEditor, (DasherMessageInfo *)pMessageInfo);
+//   }
+}
+
+extern "C" void 
+on_command(GtkDasherControl *pDasherControl, gchar *szCommand, gpointer pUserData) {
+  if(g_pDasherMain) {
+    DasherMainPrivate *pPrivate = DASHER_MAIN_GET_PRIVATE(g_pDasherMain);
+
+    if(pPrivate->pEditor)
+      dasher_editor_command(pPrivate->pEditor, szCommand);
+  }
+}
+
+// TODO: The following two should probably be made the same
+extern "C" void 
+handle_request_settings(GtkDasherControl * pDasherControl, gpointer data) {
+  // TODO: reimplement
+  //  dasher_preferences_dialogue_show(g_pPreferencesDialogue);
+}
+
+extern "C" void 
+gtk2_edit_delete_callback(GtkDasherControl *pDasherControl, const gchar *szText, int iOffset, gpointer user_data) {
+  if(g_pDasherMain) {
+    DasherMainPrivate *pPrivate = DASHER_MAIN_GET_PRIVATE(g_pDasherMain);
+
+    if(pPrivate->pEditor) {
+      gint displaylength = g_utf8_strlen(szText, -1);
+      dasher_editor_delete(pPrivate->pEditor, displaylength, iOffset);
+    }
+  }
+}
+
+extern "C" void 
+gtk2_edit_output_callback(GtkDasherControl *pDasherControl, const gchar *szText, int iOffset, gpointer user_data) {
+  if(g_pDasherMain) {
+    DasherMainPrivate *pPrivate = DASHER_MAIN_GET_PRIVATE(g_pDasherMain);
+
+    if(pPrivate->pEditor) {
+      dasher_editor_output(pPrivate->pEditor, szText, iOffset);
+    }
+  }
+}
+
+// TODO: The following aren't exported from the editor - need to fix this
+
+extern "C" void 
+convert_cb(GtkDasherControl *pDasherControl, gpointer pUserData) {
+//   if(g_pDasherMain) {
+//     DasherMainPrivate *pPrivate = DASHER_MAIN_GET_PRIVATE(g_pDasherMain);
+
+//     if(pPrivate->pEditor) {
+//       dasher_editor_convert(pPrivate->pEditor);
+//     }
+//   }
+}
+
+extern "C" void 
+protect_cb(GtkDasherControl *pDasherControl, gpointer pUserData) {
+//   if(g_pDasherMain) {
+//     DasherMainPrivate *pPrivate = DASHER_MAIN_GET_PRIVATE(g_pDasherMain);
+
+//     if(pPrivate->pEditor) {
+//       dasher_editor_protect(pPrivate->pEditor);
+//     }
+//   }
+}
