@@ -32,36 +32,42 @@ using namespace Dasher;
 class CScreen:public Dasher::CDasherScreen, private NoClones {
 public:
 
-  CScreen(HDC hdc, Dasher::screenint width, Dasher::screenint height);
+  CScreen(HDC hdc, HWND hWnd, Dasher::screenint width, Dasher::screenint height);
   ~CScreen();
 
-  void SetInterface(Dasher::CDasherInterfaceBase *DasherInterface);
+  void SetInterface(CDasherInterfaceBase * DasherInterface);
   void SetColourScheme(const Dasher::CColourIO::ColourInfo *pColours);
 
   void SetFont(const std::string &strFont);
 
-  void DrawMousePosBox(int which, int iMousePosDist);
+  void DrawMousePosBox(int which, int iMousePosDist,int layer=0);
 
   void TextSize(const std::string & String, Dasher::screenint * Width, Dasher::screenint * Height, int Size);
 
   //! Draw UTF8-encoded string String of size Size positioned at x1 and y1
+  
+  //void DrawString(const std::string & String, Dasher::screenint x1, Dasher::screenint y1, int Size,int layer=0);
   void DrawString(const std::string & String, Dasher::screenint x1, Dasher::screenint y1, int Size);
 
+  //void DrawRectangle(Dasher::screenint x1, Dasher::screenint y1, Dasher::screenint x2, Dasher::screenint y2, int Color, int iOutlineColour, Dasher::Opts::ColorSchemes ColorScheme, bool bDrawOutlines, bool bFill, int iThickness,int layer=0);
   void DrawRectangle(Dasher::screenint x1, Dasher::screenint y1, Dasher::screenint x2, Dasher::screenint y2, int Color, int iOutlineColour, Dasher::Opts::ColorSchemes ColorScheme, bool bDrawOutlines, bool bFill, int iThickness);
 
+  ///WHY is this defined like that?
+  //void CScreen::DrawCircle(screenint iCX, screenint iCY, screenint iR, int iColour, int iFillColour, int iThickness, bool bFill,int layer=0);
   void CScreen::DrawCircle(screenint iCX, screenint iCY, screenint iR, int iColour, int iFillColour, int iThickness, bool bFill);
 
   // Draw a line of fixed colour (usually black). Intended for static UI elements such as a cross-hair
   //! Draw a line between each of the points in the array
   //
   //! \param Number the number of points in the array
-  void Polyline(point * Points, int Number, int iWidth);
+  //void Polyline(point * Points, int Number, int iWidth);
 
   // Draw a line of arbitrary colour.
   //! Draw a line between each of the points in the array
   //
   //! \param Number the number of points in the array
   //! \param Colour the colour to be drawn
+  //void Polyline(point * Points, int Number, int iWidth, int Colour,int layer=0);
   void Polyline(point * Points, int Number, int iWidth, int Colour);
 
   // Draw a filled polygon - given vertices and color id
@@ -73,20 +79,30 @@ public:
   //! \param Points array of points defining the edge of the polygon
   //! \param Number number of points in the array
   //! \param Color colour of the polygon (numeric)
-  virtual void Polygon(point * Points, int Number, int Color);
+  //virtual void Polygon(point * Points, int Number, int Color);
+  //virtual void Polygon(point * Points, int Number, int Color, int iWidth,int layer);
   virtual void Polygon(point * Points, int Number, int Color, int iWidth);
 
+  //void DrawPolygon(point * Points, int Number, int Color, Dasher::Opts::ColorSchemes ColorScheme,int layer=0);
   void DrawPolygon(point * Points, int Number, int Color, Dasher::Opts::ColorSchemes ColorScheme);
   void Blank();
   void Display();
 
+  void RealDisplay(HDC hDC, RECT r);
+
   void SendMarker(int iMarker);
 
+  // TODO: These need to be implemented properly
+  virtual void SetLoadBackground (bool value) {};
+  virtual void SetCaptureBackground (bool value) {};
+
 private:
   const void point2POINT(const point * In, POINT * Out, int Number);
 
   void TextSize_Impl(const std::string & String, Dasher::screenint * Width, Dasher::screenint * Height, int Size);
 
+  HWND m_hWnd;
+
   HDC m_hdc;
   HDC m_hDCBuffer;
   HDC m_hDCBufferBackground;
